==> kcrash-5.83.0.zip: kcrash-5.83.0/autotests/metadatatest.cpp <==
/*
    SPDX-License-Identifier: LGPL-2.0-or-later
    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
*/

#include <QTest>

#include "../src/metadata.cpp"

using namespace KCrash;

class MetadataTest : public QObject
{
    Q_OBJECT
private Q_SLOTS:
    void testEverything()
    {
        QTemporaryDir tmpDir;
        QVERIFY(tmpDir.isValid());

        const QString iniFile = QStringLiteral("%1/foo.ini").arg(tmpDir.path());
        MetadataWriter *writer = nullptr;
#ifdef Q_OS_LINUX
        MetadataINIWriter iniWriter(iniFile.toLocal8Bit());
        writer = &iniWriter;
#endif
        Metadata data("BEFEHL", writer);
        data.add("--ABC", "FOO");
        data.addBool("--Meow");
        data.close();
        const int argc = data.argc;
        QCOMPARE(argc, 4);
        QCOMPARE(data.argv.at(0), QStringLiteral("BEFEHL")); // make sure we do stringy comparision
        QCOMPARE(data.argv.at(1), QStringLiteral("--ABC"));
        QCOMPARE(data.argv.at(2), QStringLiteral("FOO"));
        QCOMPARE(data.argv.at(3), QStringLiteral("--Meow"));
        QCOMPARE(data.argv.at(4), nullptr); // list should be null terminated

#ifdef Q_OS_LINUX
        QFile::exists(iniFile);
        QFile ini(iniFile);
        QVERIFY(ini.open(QFile::ReadOnly));
        QCOMPARE(ini.readLine(), "[KCrash]\n");
        QCOMPARE(ini.readLine(), "ABC=FOO\n");
        QCOMPARE(ini.readLine(), "Meow=true\n");
        QVERIFY(ini.atEnd()); // nothing after final newline
#endif
    }

    void testNoFile()
    {
        // Doesn't explode without writer
        Metadata data("BEFEHL", nullptr);
        data.add("--ABC", "FOO");
        data.close();
        const int argc = data.argc;
        QCOMPARE(argc, 3);
    }
};

QTEST_MAIN(MetadataTest)

#include "metadatatest.moc"

==> kcrash-5.86.0.zip: kcrash-5.86.0/autotests/metadatatest.cpp <==
/*
    SPDX-License-Identifier: LGPL-2.0-or-later
    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
*/

#include <QTest>

#include "../src/metadata.cpp"

using namespace KCrash;

class MetadataTest : public QObject
{
    Q_OBJECT
private Q_SLOTS:
    void testEverything()
    {
        QTemporaryDir tmpDir;
        QVERIFY(tmpDir.isValid());

        const QString iniFile = QStringLiteral("%1/foo.ini").arg(tmpDir.path());
        MetadataWriter *writer = nullptr;
#ifdef Q_OS_LINUX
        MetadataINIWriter iniWriter(iniFile.toLocal8Bit());
        writer = &iniWriter;
#endif
        Metadata data("BEFEHL");
        data.setAdditionalWriter(writer);
        data.add("--ABC", "FOO");
        data.addBool("--Meow");
        data.close();
        const int argc = data.argc;
        QCOMPARE(argc, 4);
        QCOMPARE(data.argv.at(0), QStringLiteral("BEFEHL")); // make sure we do stringy comparison
        QCOMPARE(data.argv.at(1), QStringLiteral("--ABC"));
        QCOMPARE(data.argv.at(2), QStringLiteral("FOO"));
        QCOMPARE(data.argv.at(3), QStringLiteral("--Meow"));
        QCOMPARE(data.argv.at(4), nullptr); // list should be null terminated

#ifdef Q_OS_LINUX
        QFile::exists(iniFile);
        QFile ini(iniFile);
        QVERIFY(ini.open(QFile::ReadOnly));
        QCOMPARE(ini.readLine(), "[KCrash]\n");
        QCOMPARE(ini.readLine(), "ABC=FOO\n");
        QCOMPARE(ini.readLine(), "Meow=true\n");
        QVERIFY(ini.atEnd()); // nothing after final newline
#endif
    }

    void testNoFile()
    {
        // Doesn't explode without writer
        Metadata data("BEFEHL");
        data.add("--ABC", "FOO");
        data.close();
        const int argc = data.argc;
        QCOMPARE(argc, 3);
    }
};

QTEST_MAIN(MetadataTest)

#include "metadatatest.moc"
